#! /usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time    : 2023-03-10 16:43
# @Site    :
# @File    : timer.py
# @Software: PyCharm
"""定时器"""

import subprocess
from datetime import datetime as dd, time as dt
import time
from XZGUtil.logger import conlog


def time_slot(st:str,et:str,fun):
    """时段定时器，在给定的时间段内每日循环运行指定函数"""
    DAY_START = dt(9, 28)
    DAY_END = dt(9, 30)
    while True:
        current_time = dd.now().time()
        if DAY_START <= current_time <= DAY_END:
            # 判断时候在可运行时间内
            try:
                cmd = 'python tbLiveSpider.py'
                p = subprocess.Popen(cmd, shell=True)
                p.wait()
            except:
                pass
        conlog('wait..........')
        time.sleep(10)





#! /usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time    : 2023-08-23 18:28
# @Site    :
# @File    : quickTooling.py
# @Software: PyCharm
"""
小工具
"""


def split_list(lst, size):
    """
    列表切片
    :param lst:  [1, 1, 16, 85, 9, 2, 33, 4]
    :param size: 2
    :return: [[1, 1], [16, 85], [9, 2], [33, 4]]
    """
    divided_list = []
    for i in range(0, len(lst), size):
        divided_list.append(lst[i:i + size])
    return divided_list


def remove_duplicates(lst):
    """
    列表元素去重，里面元素类型不限
    :param lst:
    :return:
    """
    unique_list = []
    seen = set()
    for item in lst:
        if isinstance(item, (list, tuple, dict)):
            item = str(item)  # 转换为字符串，以处理字典和列表的哈希问题
        if item not in seen:
            unique_list.append(item)
            seen.add(item)
    return unique_list

def sort_list(lst):
    """
    列表元素排序
    :param lst:
    :return:
    """
    sorted_lst = sorted(lst, key=lambda x: str(x))
    return sorted_lst

if __name__ == '__main__':
    lst = [1, 1, 16, 85, 9, 2, 33, 4]
    size = 3
    print(split_list(lst, size))
